@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 """
 Sub-Package DBTOOLS of Package PLIB
-Copyright (C) 2008-2015 by Peter A. Donis
+Copyright (C) 2008-2020 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -27,7 +27,7 @@ except ImportError:
     yaml = None
 
 
-__version__ = "1.0.4"
+__version__ = "1.0.5"
 
 
 def maybe(t, null_values=None, null_fields=None,
@@ -245,14 +245,15 @@ class DBInterface(object):
     def get_table_fields(cls, tablename):
         return cls.db_structure['tables'][tablename]
     
+    def _table_sql(self, tablename, fields):
+        raise NotImplementedError
+    
     @cursor_method
     def create_table(self, cursor, tablename, fields=None, commit=True, verbose=True):
         if fields is None:
             fields = self.get_table_fields(tablename)
-        sql = "CREATE TABLE {0}({1});".format(
-            tablename,
-            self.get_fieldspecs(fields)
-        )
+        fieldspecs = self.get_fieldspecs(fields)
+        sql = self._table_sql(tablename, fieldspecs)
         if verbose:
             print sql
         result = cursor.execute(sql)
@@ -284,16 +285,15 @@ class DBInterface(object):
             print "Table creation complete."
         return results
     
-    def _index_sql(self, tablename, columns, primary=False):
-        return "ALTER TABLE {0} ADD {1} ({2});".format(
-            tablename,
-            "PRIMARY KEY" if primary else "INDEX",
-            columns if isinstance(columns, basestring) else ", ".join(columns)
-        )
+    def _index_sql(self, tablename, column_str, primary=False):
+        raise NotImplementedError
     
     @cursor_method
     def create_index(self, cursor, tablename, columns, primary=False, commit=True, verbose=True):
-        sql = self._index_sql(tablename, columns, primary)
+        column_str = columns if isinstance(columns, basestring) else ", ".join(columns)
+        sql = self._index_sql(tablename, column_str, primary)
+        if not sql:
+            return None
         if verbose:
             print sql
         result = cursor.execute(sql)
@@ -314,7 +314,7 @@ class DBInterface(object):
     def create_keys(self, commit=True, verbose=True):
         index_map = self.db_structure['keys']
         results = self._create_indexes(index_map, primary=True, commit=commit, verbose=verbose)
-        if verbose:
+        if verbose and any(results):
             print "Primary key creation complete."
         return results
     
