@@ -2,7 +2,7 @@
 """
 Module MYSQL -- MySQL Database Interface
 Sub-Package DBTOOLS of Package PLIB
-Copyright (C) 2008-2015 by Peter A. Donis
+Copyright (C) 2008-2020 by Peter A. Donis
 
 Released under the GNU General Public License, Version 2
 See the LICENSE and README files for more information
@@ -40,3 +40,16 @@ class MySQLDBInterface(DBInterface):
     def _get_fieldvalue(self, row):
         # TODO: add field type and canonicalize
         return row[0]  # type is row[1] in datatype(bytes) format
+    
+    def _table_sql(self, tablename, fieldspecs):
+        return "CREATE TABLE {0}({1});".format(
+            tablename,
+            fieldspecs
+        )
+    
+    def _index_sql(self, tablename, column_str, primary=False):
+        return "ALTER TABLE {0} ADD {1} ({2});".format(
+            tablename,
+            "PRIMARY KEY" if primary else "INDEX",
+            column_str
+        )
